@@ -38,6 +38,20 @@
 //! assert_eq!(info.committish(), Some("branch"));
 //! assert_eq!(info.auth(), None);
 //! ```
+//!
+//! [HostedGitInfo] also implements the [str::FromStr] trait:
+//!
+//! ```
+//! use hosted_git_info::{HostedGitInfo, Provider};
+//!
+//! let url = "git+ssh://github.com:foo/bar.git";
+//! let info: HostedGitInfo = url.parse().unwrap();
+//! assert_eq!(info.provider(), Provider::GitHub);
+//! assert_eq!(info.user(), Some("foo"));
+//! assert_eq!(info.project(), "bar");
+//! assert_eq!(info.committish(), None);
+//! assert_eq!(info.auth(), None);
+//! ```
 
 #![deny(clippy::unwrap_used)]
 
@@ -50,6 +64,9 @@ use url::Url;
 
 mod parser;
 
+#[cfg(test)]
+mod proptest;
+
 static AUTH_SCHEMES: [&str; 5] = ["git", "https", "git+https", "http", "git+http"];
 static KNOWN_SCHEMES: [&str; 10] = [
     "http",
@@ -388,6 +405,14 @@ impl HostedGitInfo {
     }
 }
 
+impl str::FromStr for HostedGitInfo {
+    type Err = ParseError;
+
+    fn from_str(s: &str) -> Result<Self, Self::Err> {
+        HostedGitInfo::from_url(s)
+    }
+}
+
 // look for github shorthand inputs, such as npm/cli
 fn is_github_shorthand(arg: &str) -> bool {
     // it cannot contain whitespace before the first #
@@ -429,7 +454,7 @@ fn is_github_shorthand(arg: &str) -> bool {
 
     // const doesNotEndWithSlash = firstHash > -1 ? arg[firstHash - 1] !== '/' : !arg.endsWith('/')
     let does_not_end_with_slash = if let Some(first_hash) = first_hash {
-        arg.as_bytes().get(first_hash - 1) != Some(&b'/')
+        first_hash == 0 || arg.as_bytes().get(first_hash - 1) != Some(&b'/')
     } else {
         !arg.ends_with('/')
     };
